@@ -1,6 +1,5 @@
-from django.apps import apps
 from django.apps import AppConfig as DjangoAppConfig
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class AppConfig(DjangoAppConfig):
